#import "FlutterAdsPlugin.h"
#import "FlutterIosAdsSplashFactory.h"
#import "FlutterIosAdsBannerFactory.h"
#import <BUAdSDK/BUAdSDK.h>

@interface FlutterAdsPlugin ()<BURewardedVideoAdDelegate>
@property(nonatomic, strong) BURewardedVideoAd *rewardedVideoAd;
@property(nonatomic, strong) FlutterBasicMessageChannel *basicChannel;;



@end

@implementation FlutterAdsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_ads"
            binaryMessenger:[registrar messenger]];
    FlutterAdsPlugin* instance = [[FlutterAdsPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
    // 开屏广告
    [registrar registerViewFactory:[[FlutterIosAdsSplashFactory alloc] initWithMessenger:registrar.messenger] withId:@"com.flutter_to_ads_splash_view"];
    // banner广告
    [registrar registerViewFactory:[[FlutterIosAdsBannerFactory alloc] initWithMessenger:registrar.messenger] withId:@"com.flutter_to_ads_banner_view"];
    
    // 回调
    instance.basicChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/reward" binaryMessenger:[registrar messenger] codec:[FlutterStringCodec sharedInstance]];

}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"initRewardVideo" isEqualToString:call.method]) {
      NSLog(@"初始化");
      [self playRewardVideoMethodCall:call result:result];
  } else {
    result(FlutterMethodNotImplemented);
  }
}
#pragma mark 播放激励视频广告
- (void)playRewardVideoMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if (!self.rewardedVideoAd) {// 首次进来初始化
        NSString *appid = call.arguments[@"appid"];
        NSString *placementID = call.arguments[@"placementID"];
        [BUAdSDKManager setAppID:appid];
        BURewardedVideoModel *model = [[BURewardedVideoModel alloc] init];
        model.userId = [self stringWithUUID];
        self.rewardedVideoAd = [[BURewardedVideoAd alloc] initWithSlotID:placementID rewardedVideoModel:model];
        self.rewardedVideoAd.delegate = self;
        [self.rewardedVideoAd loadAdData];
        return;
    }
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    UIViewController *rootViewController = window.rootViewController;
    [self.rewardedVideoAd showAdFromRootViewController:rootViewController];
}

#pragma mark - ad delegate

- (void)rewardedVideoAdDidLoad:(BURewardedVideoAd *)rewardedVideoAd {
    NSLog(@"%s",__FUNCTION__);

}

- (void)rewardedVideoAdVideoDidLoad:(BURewardedVideoAd *)rewardedVideoAd {
    NSLog(@"%s",__FUNCTION__);
}

- (void)rewardedVideoAdWillVisible:(BURewardedVideoAd *)rewardedVideoAd {
    NSLog(@"%s",__FUNCTION__);

}

- (void)rewardedVideoAdDidVisible:(BURewardedVideoAd *)rewardedVideoAd {
    NSLog(@"%s",__FUNCTION__);

}

- (void)rewardedVideoAdWillClose:(BURewardedVideoAd *)rewardedVideoAd {
    
}

- (void)rewardedVideoAdDidClose:(BURewardedVideoAd *)rewardedVideoAd {
}

- (void)rewardedVideoAdDidClick:(BURewardedVideoAd *)rewardedVideoAd {
    
}

- (void)rewardedVideoAdServerRewardDidSucceed:(BURewardedVideoAd *)rewardedVideoAd verify:(BOOL)verify {

    [self.basicChannel sendMessage:@"finish"];
}

- (void)rewardedVideoAdServerRewardDidFail:(BURewardedVideoAd *)rewardedVideoAd {
    
}

- (void)rewardedVideoAdDidClickSkip:(BURewardedVideoAd *)rewardedVideoAd {
    
}

- (void)rewardedVideoAd:(BURewardedVideoAd *)rewardedVideoAd didFailWithError:(NSError *)error {
    NSLog(@"----素材加载失败%@",error);
}

- (void)rewardedVideoAdDidPlayFinish:(BURewardedVideoAd *)rewardedVideoAd didFailWithError:(NSError *)error {
    NSLog(@"----播放失败%@",error);
}


- (NSString *)stringWithUUID {
    CFUUIDRef uuid = CFUUIDCreate(NULL);
    CFStringRef string = CFUUIDCreateString(NULL, uuid);
    CFRelease(uuid);
    return (__bridge_transfer NSString *) string;
}

@end
